package com.aucma.base.service;

import java.util.List;
import com.aucma.base.domain.StandardDocument;

public interface IStandardDocumentService {
    public StandardDocument selectStandardDocumentByObjId(Long objId);

    public List<StandardDocument> selectStandardDocumentList(StandardDocument standardDocument);

    public int insertStandardDocument(StandardDocument standardDocument);

    public int updateStandardDocument(StandardDocument standardDocument);

    public int deleteStandardDocumentByObjIds(Long[] objIds);

    public int deleteStandardDocumentByObjId(Long objId);
}
