package com.aucma.base.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;

import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.aucma.common.annotation.Log;
import com.aucma.common.core.controller.BaseController;
import com.aucma.common.core.domain.AjaxResult;
import com.aucma.common.enums.BusinessType;
import com.aucma.base.domain.StandardDocument;
import com.aucma.base.service.IStandardDocumentService;
import com.aucma.common.utils.poi.ExcelUtil;
import com.aucma.common.core.page.TableDataInfo;

@RestController
@RequestMapping("/base/standardDocument" )
public class StandardDocumentController extends BaseController {
    @Autowired
    private IStandardDocumentService standardDocumentService;

    @PreAuthorize("@ss.hasPermi('base:standardDocument:list')" )
    @GetMapping("/list" )
    public TableDataInfo list(StandardDocument standardDocument) {
        startPage();
        List<StandardDocument> list = standardDocumentService.selectStandardDocumentList(standardDocument);
        return getDataTable(list);
    }

    @PreAuthorize("@ss.hasPermi('base:standardDocument:export')" )
    @Log(title = "标准文档" , businessType = BusinessType.EXPORT)
    @PostMapping("/export" )
    public void export(HttpServletResponse response, StandardDocument standardDocument) {
        List<StandardDocument> list = standardDocumentService.selectStandardDocumentList(standardDocument);
        ExcelUtil<StandardDocument> util = new ExcelUtil<StandardDocument>(StandardDocument. class);
        util.exportExcel(response, list, "标准文档数据" );
    }

    @PreAuthorize("@ss.hasPermi('base:standardDocument:query')" )
    @GetMapping(value = "/{objId}" )
    public AjaxResult getInfo(@PathVariable("objId" ) Long objId) {
        return success(standardDocumentService.selectStandardDocumentByObjId(objId));
    }

    @PreAuthorize("@ss.hasPermi('base:standardDocument:add')" )
    @Log(title = "标准文档" , businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody StandardDocument standardDocument) {
        return toAjax(standardDocumentService.insertStandardDocument(standardDocument));
    }

    @PreAuthorize("@ss.hasPermi('base:standardDocument:edit')" )
    @Log(title = "标准文档" , businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody StandardDocument standardDocument) {
        return toAjax(standardDocumentService.updateStandardDocument(standardDocument));
    }

    @PreAuthorize("@ss.hasPermi('base:standardDocument:remove')" )
    @Log(title = "标准文档" , businessType = BusinessType.DELETE)
    @DeleteMapping("/{objIds}" )
    public AjaxResult remove(@PathVariable Long[] objIds) {
        return toAjax(standardDocumentService.deleteStandardDocumentByObjIds(objIds));
    }

    @PreAuthorize("@ss.hasPermi('base:standardDocument:list')" )
    @GetMapping("/getList" )
    public TableDataInfo getList(StandardDocument standardDocument) {
        List<StandardDocument> list = standardDocumentService.selectStandardDocumentList(standardDocument);
        return getDataTable(list);
    }
}
